@@ -1,14 +1,14 @@
-from shutil import copyfile
-from pathlib import Path
-import sys
-import os
 import argparse
 import logging
+from pathlib import Path
+from shutil import copyfile
+from typing import List, Optional
+from pkg_resources import get_distribution
 
-from .error import *
-from .destination import Destination, Directory, Repository
-from .content import Content
 from .config import Config
+from .content import Content
+from .destination import Destination, Directory, Repository
+from .error import *
 
 logger = logging.getLogger('clibato')
 
@@ -17,21 +17,19 @@ class Clibato:
     """Clibato Controller"""
 
     ROOT = Path(__file__).parent.parent
-    VERSION = "0.9.0"
 
     def __init__(self):
         self._args = None
-        self._config = None
 
-    def execute(self):
+    def execute(self, args=List[str]) -> bool:
         """Executes the CLI"""
-        self._args = Clibato._main_argparser().parse_args()
-
+        self._args = Clibato.parse_args(args)
         self._init_logger()
+        logger.debug('Received arguments: %s', ' '.join(args))
 
         if not self._args.action:
             print("Run 'clibato --help' for help.")
-            return
+            return True
 
         logger.debug('Running action: %s', self._args.action)
 
@@ -40,9 +38,9 @@ class Clibato:
             method()
         except (ConfigError, ActionError) as error:
             logger.error(error)
-            sys.exit(1)
+            return False
 
-        sys.exit(0)
+        return True
 
     def init(self):
         """Action: Initialize configuration"""
@@ -56,34 +54,45 @@ class Clibato:
         print('')
         print('Modify the file as per your requirements.')
         print('Once done, you can run the following commands.')
-        print('clibato backup: Perform a backup')
-        print('clibato restore: Restore previous backup')
+        print('')
+        print('clibato backup: Perform a backup.')
+        print('clibato restore: Restore the last backup.')
 
     def backup(self):
         """Action: Create backup"""
-        self._init_config()
+        config = self.config()
+        dest = config.destination()
+        dest.backup(config.contents())
 
-        dest = self._config.destination()
-        dest.backup(self._config.contents())
+        print('Backup completed.')
 
     def restore(self):
         """Action: Restore backup"""
-        self._init_config()
+        config = self.config()
+        dest = config.destination()
+        dest.restore(config.contents())
 
-        dest = self._config.destination()
-        dest.restore(self._config.contents())
+        print('Restore completed.')
 
     def version(self):
         """Action: Version"""
-        print(f'Clibato v{self.VERSION}')
+        version = get_distribution('clibato').version
+        print(f'Clibato v{version}')
         if self._args.verbose:
             print('Author: Jigarius | jigarius.com')
             print('GitHub: github.com/jigarius/clibato')
 
-    def _init_config(self):
-        if not self._config:
-            path = Config.locate(self._args.config_path)
-            self._config = Config.from_file(path)
+    def config(self) -> Optional[Config]:
+        """
+        Get Config based on the --config argument.
+
+        :return: A Config object.
+        """
+        path = Config.locate(self._args.config_path)
+        if path is None:
+            raise ConfigError(f'Configuration not found: {self._args.config_path}')
+
+        return Config.from_file(path)
 
     def _init_logger(self) -> None:
         level = logging.WARNING
@@ -95,6 +104,20 @@ class Clibato:
 
         logging.basicConfig(level=level, format="%(levelname)s: %(message)s")
 
+    @staticmethod
+    def parse_args(args) -> argparse.Namespace:
+        """
+        Parse CLI arguments, i.e. ARGV.
+
+        Example
+        ------
+        Clibato.parse_args(sys.argv[1:])
+
+        :param args: CLI arguments, except the program name.
+        :return: Arguments parsed with argparse.
+        """
+        return Clibato._main_argparser().parse_args(args)
+
     @staticmethod
     def _main_argparser():
         common_parser = Clibato._common_argparser()
